@@ -22,31 +22,31 @@
 #
 #  ============================================================================
 from camelot.view.model_thread import model_function
-from camelot.core.utils import ugettext_lazy as _
 
 class Section(object):
     """A Section as displayed in the left pane of the application.  Each Section
-  contains a list of SectionItems the user can click on.  Sections should be used
-  in the definition of the ApplicationAdmin.
+contains a list of SectionItems the user can click on.  Sections should be used
+in the definition of the Application admin:
 
-    class MyApplicationAdmin(ApplicationAdmin):
-      sections = [Section('configuration')]
-
-  .. image:: /_static/configuration_section.png
+.. literalinclude:: ../../../../camelot_example/application_admin.py
+   :start-after: begin section with action
+   :end-before: end section with action
 
+.. image:: /_static/controls/navigation_pane.png
     """
-
-    def __init__(self, name, icon=None, items=[], verbose_name=None):
-        self.name = name
+        
+    def __init__( self, 
+                  verbose_name,
+                  application_admin,
+                  icon=None, 
+                  items=[] ):
         self.verbose_name = verbose_name
         self.icon = icon
-        self.items = structure_to_section_items(items)
-
-    def get_name(self):
-        return self.name
+        self.items = structure_to_section_items( items, application_admin )
+        self.admin = application_admin
 
     def get_verbose_name(self):
-        return self.verbose_name or _(self.name.capitalize())
+        return self.verbose_name
 
     def get_icon(self):
         from camelot.view.art import Icon
@@ -56,46 +56,38 @@ class Section(object):
     def get_items(self):
         return self.items
 
-def structure_to_sections(structure):
-    """Convert a list of python objects to a list of sections, using
-  applying these rules on each of the elements in the list :
-
-    - if the element is a instance of Section, leave it as it is
-    - if the element is an instance of a basestr, construct a Section
-      for it"""
-
-    def rule(element):
-        if isinstance(element, (Section,)):
-            return element
-        else:
-            return Section(element)
-
-    return [rule(section) for section in structure]
-
 class SectionItem(object):
     """An item inside a section, the user can click on and trigger an action."""
 
-    def __init__(self, action, verbose_name=None):
-        from camelot.admin.application_action import structure_to_application_action
-        self.action = structure_to_application_action(action)
+    def __init__( self,
+                  action, 
+                  application_admin,
+                  verbose_name = None ):
+        from camelot.admin.action.application_action import structure_to_application_action
         self.verbose_name = verbose_name
+        self.action = structure_to_application_action(action, application_admin)
+        self.state = self.action.get_state( None )
 
     def get_verbose_name(self):
-        return self.verbose_name or self.action.get_verbose_name()
+        return self.verbose_name or self.state.verbose_name
 
     def get_action(self):
         return self.action
         
     def get_icon(self):
-        return self.action.get_icon()
+        return self.state.icon
+    
+    def get_tooltip(self):
+        return self.state.tooltip
 
-def structure_to_section_items(structure):
+    def get_modes(self):
+        return self.state.modes
+    
+def structure_to_section_items(structure, application_admin):
 
     def rule(element):
         if isinstance(element, (SectionItem,)):
             return element
-        return SectionItem(element)
+        return SectionItem(element, application_admin)
 
     return [rule(item) for item in structure]
-
-
