@@ -1,6 +1,6 @@
 #  ============================================================================
 #
-#  Copyright (C) 2007-2010 Conceptive Engineering bvba. All rights reserved.
+#  Copyright (C) 2007-2011 Conceptive Engineering bvba. All rights reserved.
 #  www.conceptive.be / project-camelot@conceptive.be
 #
 #  This file is part of the Camelot Library.
@@ -39,6 +39,7 @@ from imagedelegate import ImageDelegate
 from integerdelegate import IntegerDelegate
 from intervalsdelegate import IntervalsDelegate
 from languagedelegate import LanguageDelegate
+from localfiledelegate import LocalFileDelegate
 from manytomanydelegate import ManyToManyDelegate
 from many2onedelegate import Many2OneDelegate
 from one2manydelegate import One2ManyDelegate
@@ -54,6 +55,43 @@ from notedelegate import NoteDelegate
 from labeldelegate import LabelDelegate
 from monthsdelegate import MonthsDelegate
 
+__all__ = [
+    DelegateManager.__name__,
+    BoolDelegate.__name__,
+    TextBoolDelegate.__name__,
+    ChartDelegate.__name__,
+    CodeDelegate.__name__,
+    ColorDelegate.__name__,
+    ColoredFloatDelegate.__name__,
+    ComboBoxDelegate.__name__,
+    CurrencyDelegate.__name__,
+    CustomDelegate.__name__,
+    DateDelegate.__name__,
+    DateTimeDelegate.__name__,
+    EnumerationDelegate.__name__,
+    FileDelegate.__name__,
+    FloatDelegate.__name__,
+    ImageDelegate.__name__,
+    IntegerDelegate.__name__,
+    IntervalsDelegate.__name__,
+    LanguageDelegate.__name__,
+    LocalFileDelegate.__name__,
+    ManyToManyDelegate.__name__,
+    Many2OneDelegate.__name__,
+    One2ManyDelegate.__name__,
+    ManyToOneChoicesDelegate.__name__,
+    PlainTextDelegate.__name__,
+    RichTextDelegate.__name__,
+    StarDelegate.__name__,
+    TextEditDelegate.__name__,
+    TimeDelegate.__name__,
+    VirtualAddressDelegate.__name__,
+    SmileyDelegate.__name__,
+    NoteDelegate.__name__,
+    LabelDelegate.__name__,
+    MonthsDelegate.__name__,
+]
+
 doc = """Camelot includes a number of Qt delegates, most of them are used as default
 delegates for the various sqlalchemy and camelot field types.
 
@@ -77,9 +115,10 @@ _add_subclasses(CustomDelegate)
 
 custom_delegates.sort(key=lambda d:d.__name__)
 for custom_delegate in custom_delegates:
-    doc = doc + custom_delegate.__name__ + '\n' + '-'*len(custom_delegate.__name__) + '\n'
+    doc = doc + '\n' + custom_delegate.__name__ + '\n' + '-'*len(custom_delegate.__name__) + '\n'
     if hasattr(custom_delegate, '__doc__') and custom_delegate.__doc__:
         doc = doc + custom_delegate.__doc__ + '\n'
 
 __doc__ = doc
 
+
