@@ -1,6 +1,6 @@
 #  ============================================================================
 #
-#  Copyright (C) 2007-2010 Conceptive Engineering bvba. All rights reserved.
+#  Copyright (C) 2007-2011 Conceptive Engineering bvba. All rights reserved.
 #  www.conceptive.be / project-camelot@conceptive.be
 #
 #  This file is part of the Camelot Library.
@@ -22,6 +22,7 @@
 #
 #  ============================================================================
 
+
 from PyQt4 import QtGui
 from PyQt4 import QtCore
 from PyQt4.QtCore import Qt
@@ -40,23 +41,23 @@ class BoolEditor(QtGui.QCheckBox, AbstractCustomEditor):
                  parent=None,
                  minimum=constants.camelot_minint,
                  maximum=constants.camelot_maxint,
-                 editable=True,
-		 nullable=True,
+                 nullable=True,
+                 field_name = 'boolean',
                  **kwargs):
         QtGui.QCheckBox.__init__(self, parent)
         AbstractCustomEditor.__init__(self)
-        self.setEnabled(editable)
+        self.setObjectName( field_name )
         self._nullable = nullable
-        if self._nullable:
-            self.setTristate( True )
+        #if self._nullable:
+        #    self.setTristate( True )
         self.stateChanged.connect(self._state_changed)
 
     def set_value(self, value):
         value = AbstractCustomEditor.set_value(self, value)
         if value:
             self.setCheckState(Qt.Checked)
-        elif value==None and self._nullable:
-            self.setCheckState(Qt.PartiallyChecked)
+        #elif value==None and self._nullable:
+        #    self.setCheckState(Qt.PartiallyChecked)
         else:
             self.setCheckState(Qt.Unchecked)
 
@@ -65,9 +66,9 @@ class BoolEditor(QtGui.QCheckBox, AbstractCustomEditor):
         if value_loading is not None:
             return value_loading
         state = self.checkState()
-        if state==Qt.PartiallyChecked:
-            return None
-        elif state==Qt.Unchecked:
+        #if state==Qt.PartiallyChecked:
+        #    return None
+        if state==Qt.Unchecked:
             return False
         return True
 
