@@ -29,7 +29,40 @@ from wideeditor import WideEditor
 from customeditor import CustomEditor
 from camelot.view.art import Icon
 
+class CustomTextEdit(QtGui.QTextEdit):
+    """
+    A TextEdit editor that sends editingFinished events 
+    when the text was changed and focus is lost.
+    """
 
+    editingFinished = QtCore.pyqtSignal()
+    receivedFocus = QtCore.pyqtSignal()
+    
+    def __init__(self, parent):
+        super(CustomTextEdit, self).__init__(parent)
+        self._changed = False
+        self.setTabChangesFocus( True )
+        self.textChanged.connect( self._handle_text_changed )
+
+    def focusInEvent(self, event):
+        super(CustomTextEdit, self).focusInEvent( event )
+        self.receivedFocus.emit()
+
+    def focusOutEvent(self, event):
+        if self._changed:
+            self.editingFinished.emit()
+        super(CustomTextEdit, self).focusOutEvent( event )
+
+    def _handle_text_changed(self):
+        self._changed = True
+
+    def setTextChanged(self, state=True):
+        self._changed = state
+
+    def setHtml(self, html):
+        QtGui.QTextEdit.setHtml(self, html)
+        self._changed = False
+                
 class RichTextEditor(CustomEditor, WideEditor):
 
     def __init__(self, 
@@ -44,40 +77,6 @@ class RichTextEditor(CustomEditor, WideEditor):
         self.setSizePolicy( QtGui.QSizePolicy.Expanding,
                             QtGui.QSizePolicy.Expanding )
 
-        class CustomTextEdit(QtGui.QTextEdit):
-            """
-            A TextEdit editor that sends editingFinished events 
-            when the text was changed and focus is lost.
-            """
-
-            editingFinished = QtCore.pyqtSignal()
-            receivedFocus = QtCore.pyqtSignal()
-            
-            def __init__(self, parent):
-                super(CustomTextEdit, self).__init__(parent)
-                self._changed = False
-                self.setTabChangesFocus( True )
-                self.textChanged.connect( self._handle_text_changed )
-
-            def focusInEvent(self, event):
-                super(CustomTextEdit, self).focusInEvent( event )
-                
-                self.receivedFocus.emit()
-
-            def focusOutEvent(self, event):
-                if self._changed:
-                    self.editingFinished.emit()
-
-            def _handle_text_changed(self):
-                self._changed = True
-
-            def setTextChanged(self, state=True):
-                self._changed = state
-
-            def setHtml(self, html):
-                QtGui.QTextEdit.setHtml(self, html)
-                self._changed = False
-
         self.textedit = CustomTextEdit(self)
 
         self.initToolbar() # Has to be invoked before the connect's below.
