@@ -1,6 +1,6 @@
 #  ============================================================================
 #
-#  Copyright (C) 2007-2010 Conceptive Engineering bvba. All rights reserved.
+#  Copyright (C) 2007-2011 Conceptive Engineering bvba. All rights reserved.
 #  www.conceptive.be / project-camelot@conceptive.be
 #
 #  This file is part of the Camelot Library.
@@ -28,37 +28,32 @@ import logging
 logger = logging.getLogger('camelot.view.controls.modeltree')
 
 from PyQt4 import QtGui
-from PyQt4 import QtCore
 from PyQt4.QtCore import Qt
 
-from camelot.view.art import Icon
 from camelot.core.utils import ugettext as _
 
-QT_MAJOR_VERSION = float('.'.join(str(QtCore.QT_VERSION_STR).split('.')[0:2]))
-
-
 class ModelItem(QtGui.QTreeWidgetItem):
     """Custom tree item widget"""
 
-    def __init__(self, parent, columns_names):
+    def __init__(self, parent, columns_names, section_item):
         logger.debug('creating new modelitem')
-        QtGui.QTreeWidgetItem.__init__(self, parent, columns_names)
-        self.column = 0
-        self.set_icon()
+        super(ModelItem, self).__init__(parent, columns_names)
+        
+        self.textColumn = 0
+        self.iconColumn = 1
+        self.section_item = section_item
 
-        self.setToolTip(self.column, _('Right click to open in New Tab'))
+        for column in (self.textColumn, self.iconColumn):
+            self.setToolTip(column, _('Right click to open in New Tab'))
 
     def _underline(self, enable=False):
-        font = self.font(self.column)
+        font = self.font(self.textColumn)
         font.setUnderline(enable)
-        self.setFont(self.column, font)
-
-    def set_icon(self, qicon=None):
-        if qicon is None:
-            qicon = Icon('tango/16x16/actions/window-new.png').getQIcon()
-        self.setIcon(self.column, qicon)
-
+        self.setFont(self.textColumn, font)
 
+    def set_icon(self, icon):
+        self.setIcon(self.iconColumn, icon)
+        
 class ModelTree(QtGui.QTreeWidget):
     """Custom tree widget"""
 
@@ -67,18 +62,30 @@ class ModelTree(QtGui.QTreeWidget):
         super(ModelTree, self).__init__(parent)
         # we don't select entire rows
         self.setSelectionBehavior(QtGui.QAbstractItemView.SelectItems)
+        
         # we track mouse movement when no button is pressed
         self.setMouseTracking(True)
         self.header_labels = header_labels
+        
+        self.setColumnCount(2)
+        self.setColumnWidth(0, 160)
+        self.setColumnWidth(1, 18)
+        self.setHorizontalScrollBarPolicy( Qt.ScrollBarAlwaysOff )
+        self.setSelectionBehavior( self.SelectRows )
+        
         self.clear_model_items()
+        self.clear_section_items()
         self.fix_header_labels()
 
+    def resizeEvent(self, event):
+        self.setColumnWidth(0, self.width()  - 30 )
+        
     def fix_header_labels(self):
-        if QT_MAJOR_VERSION > 4.3:
-            self.setHeaderHidden(True)
-        else:
-            self.setHeaderLabels(self.header_labels)
+        self.setHeaderHidden(True)
 
+    def clear_section_items(self):
+        self.section_items = []
+        
     def clear_model_items(self):
         self.modelitems = []
 
@@ -101,3 +108,4 @@ class ModelTree(QtGui.QTreeWidget):
         item = self.itemAt(self.mapFromGlobal(self.cursor().pos()))
         if item:
             item._underline(True)
+
