@@ -86,11 +86,17 @@ class Filter(object):
         from elixir import session
         filter_names = []
         joins = []
-        table = admin.entity.table
+        #
+        # in case of inheritance, use the local table to be able to join,
+        # otherwise use the mapped table, to be able to filter on views
+        #
+        if admin.mapper!=admin.mapper.base_mapper:
+            table = admin.mapper.local_table
+        else:
+            table = admin.mapper.mapped_table
         path = self.attribute.split('.')
         for field_name in path:
             attributes = admin.get_field_attributes(field_name)
-            
             filter_names.append(attributes['name'])
             # @todo: if the filter is not on an attribute of the relation, but on the relation itselves
             if 'target' in attributes:
@@ -126,19 +132,22 @@ class Filter(object):
         
         return (filter_names[0],[(_('All'), lambda q: q)] + options)
 
-class FilterWidget(QtGui.QGroupBox):
+class FilterWidget( QtGui.QGroupBox ):
     """A box containing a filter that can be applied on a table view, this filter is
     based on the distinct values in a certain column"""
   
     filter_changed_signal = QtCore.pyqtSignal()
     
     def __init__(self, name, choices, parent):
-        QtGui.QGroupBox.__init__(self, unicode(name), parent)
+        super( FilterWidget, self ).__init__( unicode( name ), parent )
+        layout = QtGui.QHBoxLayout()
+        layout.setSpacing( 2 )
+        self.setLayout( layout )
         self.group = QtGui.QButtonGroup(self)
         self.item = name
         self.unique_values = []
         self.choices = None
-        self.setChoices(choices)
+        self.setChoices( choices )
          
     @QtCore.pyqtSlot(bool)
     def emit_filter_changed(self, state):
@@ -146,16 +155,18 @@ class FilterWidget(QtGui.QGroupBox):
     
     def setChoices(self, choices):
         self.choices = choices
-        layout = QtGui.QVBoxLayout()
+        layout = self.layout()
+        button_layout = QtGui.QVBoxLayout()
         
         for i, name in enumerate([unicode(c[0]) for c in choices]):
             button = QtGui.QRadioButton(name, self)
-            layout.addWidget(button)
+            button_layout.addWidget(button)
             self.group.addButton(button, i)
             if i==0:
                 button.setChecked(True)
             button.toggled.connect( self.emit_filter_changed )
-        layout.addStretch()
+            
+        layout.addLayout( button_layout )
         self.setLayout(layout)
     
     def decorate_query(self, query):
@@ -171,19 +182,20 @@ class GroupBoxFilter(Filter):
     def render(self, parent, name, options):
         return FilterWidget(name, options, parent)
       
-class GroupBoxFilterWidget(QtGui.QGroupBox):
+class GroupBoxFilterWidget( QtGui.QGroupBox ):
     """Flter widget based on a QGroupBox"""
   
     filter_changed_signal = QtCore.pyqtSignal()
     
     def __init__(self, name, choices, parent):
-        QtGui.QGroupBox.__init__(self, unicode(name), parent)
+        super( GroupBoxFilterWidget, self ).__init__( unicode( name ), parent )
         layout = QtGui.QVBoxLayout()
+        layout.setSpacing( 2 )
         self.choices = choices
         combobox = QtGui.QComboBox(self)
         for i,(name,decorator) in enumerate(choices):
             combobox.insertItem(i, unicode(name), QtCore.QVariant(decorator))
-        layout.addWidget(combobox)
+        layout.addWidget( combobox )
         self.setLayout(layout)
         self.current_index = 0
         combobox.currentIndexChanged.connect( self.emit_filter_changed )
@@ -226,19 +238,20 @@ class EditorFilter(Filter):
         name = self._verbose_name or field_attributes['name']
         return name, (admin.entity, self._field_name, field_attributes)
         
-class DateFilterWidget(QtGui.QGroupBox):
+class DateFilterWidget( QtGui.QGroupBox ):
     """Filter widget based on a DateEditor"""
   
     filter_changed_signal = QtCore.pyqtSignal()
     
     def __init__(self, name, query_decorator, default, parent):
-        QtGui.QGroupBox.__init__(self, unicode(name), parent)
+        super( DateFilterWidget, self ).__init__( unicode( name ), parent )
         layout = QtGui.QVBoxLayout()
+        layout.setSpacing( 2 )
         self.date_editor = DateEditor(parent=self, nullable=True)
         self.date_editor.set_value(default)
         self.query_decorator = query_decorator
-        layout.addWidget(self.date_editor)
-        self.setLayout(layout)
+        layout.addWidget( self.date_editor )
+        self.setLayout( layout )
         self.date_editor.editingFinished.connect(self.emit_filter_changed)
             
     @QtCore.pyqtSlot()
