@@ -30,6 +30,8 @@ well.  Form classes can be used recursive.
 import logging
 logger = logging.getLogger( 'camelot.view.forms' )
 
+from PyQt4 import QtCore, QtGui
+
 from camelot.view.model_thread import gui_function
 
 class Form( list ):
@@ -167,23 +169,27 @@ to render a form::
         yield '</w:tbl>'
 
     @gui_function
-    def render( self, widgets, parent = None, nomargins = False):
-        """:param widgets: a dictionary mapping each field in this form to a tuple
-        of (label, widget editor)
+    def render( self, widgets, parent = None, toplevel = False):
+        """
+        :param widgets: a :class:`camelot.view.controls.formview.FormEditors` object
+            that is able to create the widgets for this form
+        :param parent: the :class:`QtGui.QWidget` in which the form is placed
+        :param toplevel: a :keyword:`boolean` indicating if this form is toplevel,
+            or a child form of another form.  A toplevel form will be expanding,
+            while a non toplevel form is only expanding if it contains other
+            expanding elements.
 
         :return: a QWidget into which the form is rendered
         """
-        logger.debug( 'rendering %s' % self.__class__.__name__ )
+        logger.debug( 'rendering %s' % (self.__class__.__name__) )
         from camelot.view.controls.editors.wideeditor import WideEditor
-
-        from PyQt4 import QtGui
+        form_widget = QtGui.QWidget( parent )
         form_layout = QtGui.QGridLayout()
-
         # where 1 column in the form is a label and a field, so two columns in the grid
         columns = min(self._columns, len(self))
         # make sure all columns have the same width
-        if columns > 1:
-            for i in range(columns*2):
+        for i in range(columns*2):
+            if i%2:
                 form_layout.setColumnStretch(i, 1)
 
         row_span = 1
@@ -214,62 +220,60 @@ to render a form::
 
         has_vertical_expanding_row = False
         for field in self:
+            size_policy = None
             if isinstance( field, Form ):
-                has_vertical_expanding_row = True
                 c.next_empty_row()
                 col_span = 2 * columns
-                f = field.render( widgets, parent, True )
+                f = field.render( widgets, parent, False )
                 if isinstance( f, QtGui.QLayout ):
+                    #
+                    # this should maybe be recursive ??
+                    #
+                    for layout_item_index in range( f.count() ):
+                        layout_item = f.itemAt( layout_item_index )
+                        layout_item_widget = layout_item.widget()
+                        if layout_item_widget and layout_item_widget.sizePolicy().verticalPolicy() == QtGui.QSizePolicy.Expanding:
+                            has_vertical_expanding_row = True
                     form_layout.addLayout( f, c.row, c.col, row_span, col_span )
                 else:
                     form_layout.addWidget( f, c.row, c.col, row_span, col_span )
+                    size_policy = f.sizePolicy()
                 c.next_row()
-            elif field in widgets:
-                label, editor = widgets[field]
-                if isinstance( editor, ( WideEditor, ) ):
-                    c.next_empty_row()
-                    col_span = 2 * columns
-                    if label:
-                        form_layout.addWidget( label, c.row, c.col, row_span, col_span )
-                        c.next_row()
-                    form_layout.addWidget( editor, c.row, c.col, row_span, col_span )
-                    c.next_row()
-                else:
-                    col_span = 1
-                    if label:
-                        form_layout.addWidget( label, c.row, c.col, row_span, col_span )
-                    form_layout.addWidget( editor, c.row, c.col + 1, row_span, col_span )
-                    c.next_col()
-                size_policy = editor.sizePolicy()
-                if size_policy.verticalPolicy()==QtGui.QSizePolicy.Expanding:
-                    has_vertical_expanding_row = True
             else:
-                logger.warning('ProgrammingError : widgets should contain a widget for field %s'%unicode(field))
+                editor = widgets.create_editor( field, form_widget )
+                if editor != None:
+                    if isinstance( editor, ( WideEditor, ) ):
+                        c.next_empty_row()
+                        col_span = 2 * columns
+                        label = widgets.create_label( field, editor, form_widget )
+                        if label:
+                            form_layout.addWidget( label, c.row, c.col, row_span, col_span )
+                            c.next_row()
+                        form_layout.addWidget( editor, c.row, c.col, row_span, col_span )
+                        c.next_row()
+                    else:
+                        col_span = 1
+                        label = widgets.create_label( field, editor, form_widget )
+                        if label:
+                            form_layout.addWidget( label, c.row, c.col, row_span, col_span )
+                        form_layout.addWidget( editor, c.row, c.col + 1, row_span, col_span )
+                        c.next_col()
+                    size_policy = editor.sizePolicy()
+                else:
+                    logger.warning('ProgrammingError : widgets should contain a widget for field %s'%unicode(field))
+            if size_policy and size_policy.verticalPolicy() == QtGui.QSizePolicy.Expanding:
+                has_vertical_expanding_row = True
 
-        if len(self) and form_layout.count():
-#            # get last item in the layout
-#            last_item = form_layout.itemAt( form_layout.count() - 1 )
-#
-#            # if last item does not contain a widget, 0 is returned
-#            # which is fine with the isinstance test
-#            w = last_item.widget()
-#
-#            # add stretch only if last item is not expandable
-#            last_size_policy = w.sizePolicy()
-#            if last_size_policy.verticalPolicy()==QtGui.QSizePolicy.Expanding:
-#                pass
-#            else:
-            if not has_vertical_expanding_row:
-                form_layout.setRowStretch( form_layout.rowCount(), 1 )
-
-        form_widget = QtGui.QWidget( parent )
+        if (not has_vertical_expanding_row) and toplevel and form_layout.rowCount():
+            form_layout.setRowStretch( form_layout.rowCount(), 1 )
 
         # fix embedded forms
-        if nomargins:
+        if not toplevel:
             form_layout.setContentsMargins( 0, 0, 0, 0 )
-
-        form_widget.setSizePolicy( QtGui.QSizePolicy.Expanding,
-                                   QtGui.QSizePolicy.Expanding )
+  
+        if toplevel or has_vertical_expanding_row:
+            form_widget.setSizePolicy( QtGui.QSizePolicy.Expanding,
+                                       QtGui.QSizePolicy.Expanding )
         form_widget.setLayout( form_layout )
 
         if self._scrollbars:
@@ -278,9 +282,10 @@ to render a form::
             scroll_area.setWidget( form_widget )
             scroll_area.setWidgetResizable( True )
             scroll_area.setFrameStyle( QtGui.QFrame.NoFrame )
-            #scroll_area.setStyleSheet('background-color: transparent;')
             return scroll_area
 
+        logger.debug( 'end rendering %s' % self.__class__.__name__ )
+        
         return form_widget
 
 
@@ -306,7 +311,7 @@ class Label( Form ):
 
 
     @gui_function
-    def render( self, widgets, parent = None, nomargins = False ):
+    def render( self, widgets, parent = None, toplevel = False ):
         from PyQt4 import QtGui
         if self.style:
             widget = QtGui.QLabel( '<p align="%s" style="%s">%s</p>' % (self.alignment, self.style,unicode(self.label)) )
@@ -314,14 +319,81 @@ class Label( Form ):
             widget = QtGui.QLabel( '<p align="%s">%s</p>' % (self.alignment,unicode(self.label)) )
         return widget
 
+class DelayedTabWidget( QtGui.QTabWidget ):
+    """Helper class for :class:`TabForm` to delay the creation of tabs to
+the moment the tab is shown.
+    """
+    
+    def __init__( self,  widgets, tabs, parent = None ):
+        super( DelayedTabWidget, self ).__init__( parent )
+        self._widgets = widgets
+        self._forms = []
+        #
+        # keep track for each of the tabs wether they are expanding,
+        #
+        self._vertical_expanding = [False] * len(tabs)
+        #
+        # set dummy tab widgets
+        #
+        for tab_label, tab_form in tabs:
+            self._forms.append( tab_form )
+            tab_widget = QtGui.QWidget( self )
+            self.addTab( tab_widget, unicode(tab_label) )
+        #
+        # render the first tab and continue rendering until we have
+        # a tab with an expanding size policy, because then we know
+        # the widget itself should be expanding, and we can delay
+        # the rendering of the other tabs
+        #
+        for i in range( len(tabs) ):
+            self.render_tab( i )
+            if sum(self._vertical_expanding):
+                self.setSizePolicy(QtGui.QSizePolicy.Expanding, QtGui.QSizePolicy.Expanding)
+                #
+                # if one of the tabs is expanding, the others should have spacer
+                # items to stretch
+                #
+                for j, vertical_expanding_of_widget in zip(range(i), self._vertical_expanding):
+                    if vertical_expanding_of_widget == False:
+                        tab_widget = self.widget( j )
+                        tab_widget.layout().addStretch( 1 )                
+                break
+        self.currentChanged.connect( self.render_tab )
+            
+    @QtCore.pyqtSlot( int )
+    def render_tab( self, index ):
+        """
+        Render the tab at index
+        """
+        tab_widget = self.widget( index )
+        layout = tab_widget.layout()
+        if layout != None:
+            # this tab has been rendered before
+            return
+        layout = QtGui.QVBoxLayout( tab_widget )
+        tab_form = self._forms[index]
+        tab_form_widget = tab_form.render( self._widgets, tab_widget, False )
+        layout.addWidget( tab_form_widget )
+        tab_widget.setLayout( layout )
+        size_policy = tab_form_widget.sizePolicy()
+        if size_policy.verticalPolicy() == QtGui.QSizePolicy.Expanding:
+            self._vertical_expanding[index] = True
+        else:
+            self._vertical_expanding[index] = False
+        #
+        # if other widgets are expanding, and this one isn't, add some stretch
+        #
+        if self._vertical_expanding[index] == False and sum(self._vertical_expanding):
+            tab_widget.layout().addStretch( 1 )
+
 class TabForm( Form ):
     """
-  Render forms within a QTabWidget::
+Render forms within a QTabWidget::
 
     from = TabForm([('First tab', ['title', 'short_description']),
                     ('Second tab', ['director', 'release_date'])])
 
-  .. image:: /_static/form/tab_form.png
+.. image:: /_static/form/tab_form.png
     """
 
     NORTH = 'North'
@@ -398,23 +470,12 @@ class TabForm( Form ):
                 yield field
 
     @gui_function
-    def render( self, widgets, parent = None, nomargins = False ):
+    def render( self, widgets, parent = None, toplevel = False ):
         logger.debug( 'rendering %s' % self.__class__.__name__ )
-        from PyQt4 import QtGui
-        widget = QtGui.QTabWidget( parent )
-        widget.setTabPosition(getattr(QtGui.QTabWidget, self.position))
-        vertical_expanding = False
-        for tab_label, tab_form in self.tabs:
-            tab_form_widget = tab_form.render( widgets, widget )
-            size_policy = tab_form_widget.sizePolicy()
-            if size_policy.verticalPolicy()==QtGui.QSizePolicy.Expanding:
-                vertical_expanding = True
-            widget.addTab( tab_form_widget, unicode(tab_label) )
-        if vertical_expanding:
-            widget.setSizePolicy(QtGui.QSizePolicy.Expanding, QtGui.QSizePolicy.Expanding)
+        widget = DelayedTabWidget( widgets, self.tabs, parent )
+        widget.setTabPosition( getattr(QtGui.QTabWidget, self.position) )                
         return widget
 
-
 class HBoxForm( Form ):
     """
   Render different forms in a horizontal box::
@@ -448,13 +509,12 @@ class HBoxForm( Form ):
                 yield field
 
     @gui_function
-    def render( self, widgets, parent = None, nomargins = False ):
+    def render( self, widgets, parent = None, toplevel = False ):
         logger.debug( 'rendering %s' % self.__class__.__name__ )
-        from PyQt4 import QtGui
         widget = QtGui.QWidget( parent )
         form_layout = QtGui.QHBoxLayout()
         for form in self.columns:
-            f = form.render( widgets, widget, nomargins )
+            f = form.render( widgets, widget, False )
             if isinstance( f, QtGui.QLayout ):
                 form_layout.addLayout( f )
             else:
@@ -494,13 +554,12 @@ class VBoxForm( Form ):
         return 'VBoxForm [ %s\n         ]' % ( '         \n'.join( [unicode( form ) for form in self.rows] ) )
 
     @gui_function
-    def render( self, widgets, parent = None, nomargins = False ):
+    def render( self, widgets, parent = None, toplevel = False ):
         logger.debug( 'rendering %s' % self.__class__.__name__ )
-        from PyQt4 import QtGui
         widget = QtGui.QWidget( parent )
         form_layout = QtGui.QVBoxLayout()
         for form in self.rows:
-            f = form.render( widgets, widget, nomargins )
+            f = form.render( widgets, widget, False )
             if isinstance( f, QtGui.QLayout ):
                 form_layout.addLayout( f )
             else:
@@ -509,6 +568,7 @@ class VBoxForm( Form ):
         return widget
 
 class ColumnSpan( Form ):
+    
     def __init__(self, field=None, num=2):
         self.num = num
         self.field = field
@@ -551,8 +611,7 @@ class GridForm( Form ):
             row.append(additional_field)
 
     @gui_function
-    def render( self, widgets, parent = None, nomargins = False ):
-        from PyQt4 import QtGui
+    def render( self, widgets, parent = None, toplevel = False ):
         widget = QtGui.QWidget( parent )
         grid_layout = QtGui.QGridLayout()
         for i, row in enumerate( self._grid ):
@@ -567,12 +626,12 @@ class GridForm( Form ):
                     grid_layout.addWidget( field.render( widgets, parent ), i, j + skip, 1, num )
                     skip += num - 1
                 else:
-                    _label, editor = widgets[field]
+                    editor = widgets.create_editor( field, widget )
                     grid_layout.addWidget( editor, i, j + skip, 1, num )
                     skip += num - 1
 
         widget.setLayout( grid_layout )
-        if nomargins:
+        if not toplevel:
             grid_layout.setContentsMargins( 0, 0, 0, 0 )
 
         return widget
@@ -585,9 +644,9 @@ class WidgetOnlyForm( Form ):
         super( WidgetOnlyForm, self ).__init__( [field] )
 
     @gui_function
-    def render( self, widgets, parent = None, nomargins = False ):
+    def render( self, widgets, parent = None, toplevel = False ):
         logger.debug( 'rendering %s' % self.__class__.__name__ )
-        _label, editor = widgets[self.get_fields()[0]]
+        editor = widgets.create_editor( self.get_fields()[0], parent )
         return editor
 
 class GroupBoxForm( Form ):
@@ -609,14 +668,13 @@ class GroupBoxForm( Form ):
         Form.__init__( self, content, scrollbars, columns=columns )
 
     @gui_function
-    def render( self, widgets, parent = None, nomargins = False ):
-        from PyQt4 import QtGui
+    def render( self, widgets, parent = None, toplevel = False ):
         widget = QtGui.QGroupBox( unicode(self.title), parent )
         layout = QtGui.QVBoxLayout()
         if self.min_width and self.min_height:
             widget.setMinimumSize ( self.min_width, self.min_height )
         widget.setLayout( layout )
-        form = Form.render( self, widgets, widget, nomargins )
+        form = Form.render( self, widgets, widget, False )
         layout.addWidget( form )
         return widget
 
