@@ -4,10 +4,12 @@ from PyQt4 import QtGui
 import logging
 import unittest
 import os
+import time
 
 from camelot.test import ModelThreadTestCase, EntityViewsTest, SchemaTest
 from camelot.view.art import ColorScheme
 
+from PyQt4 import QtGui, QtCore
 from PyQt4.QtGui import *
 from PyQt4.QtCore import *
 
@@ -243,6 +245,15 @@ class EditorsTest(ModelThreadTestCase):
         editor.set_field_attributes( editable = True, tooltip = 'tooltip')
         self.grab_widget( editor, 'editable_tooltip')
 
+    def test_LocalFileEditor( self ):
+        editor = self.editors.LocalFileEditor( parent=None )
+        self.assertEqual( editor.get_value(), self.ValueLoading )
+        editor.set_value( '/home/lancelot/quests.txt' )
+        self.grab_default_states( editor )
+        self.assertEqual( editor.get_value(), '/home/lancelot/quests.txt' )
+        editor.set_value( self.ValueLoading )
+        self.assertEqual( editor.get_value(), self.ValueLoading )
+        
     def test_StarEditor(self):
         editor = self.editors.StarEditor(parent=None, maximum=5)
         self.assertEqual( editor.get_value(), self.ValueLoading )
@@ -489,18 +500,28 @@ class FormTest(ModelThreadTestCase):
 
     def setUp(self):
         ModelThreadTestCase.setUp(self)
-        from camelot.view.controls.editors import TextLineEditor, DateEditor
-        self.widgets = {
-          'title':(QLabel('Title'), TextLineEditor(parent=None, editable=True)),
-          'short_description':(QLabel('Short description'), TextLineEditor(parent=None, editable=True)),
-          'director':(QLabel('Director'), TextLineEditor(parent=None, editable=True)),
-          'release_date':(QLabel('Release date'), DateEditor(parent=None, editable=True)),
-        }
+        from camelot.view.controls.formview import FormEditors
         from elixir import entities
         self.entities = [e for e in entities]
         from camelot.admin.application_admin import ApplicationAdmin
+        from camelot.view.proxy.queryproxy import QueryTableProxy
         from camelot.model.authentication import Person
+        from camelot_example.model import Movie
         self.app_admin = ApplicationAdmin()
+        self.movie_admin = self.app_admin.get_related_admin( Movie )
+        
+        self.movie_model = QueryTableProxy( self.movie_admin, 
+                                            lambda:Movie.query,
+                                            self.movie_admin.get_fields )
+        
+        widget_mapper = QtGui.QDataWidgetMapper()
+        widget_mapper.setModel( self.movie_model )
+        widget_mapper.setItemDelegate( self.movie_model.getItemDelegate() )
+        self.widgets = FormEditors( self.movie_admin.get_fields(),
+                                    widget_mapper,
+                                    self.movie_model.getItemDelegate(),
+                                    self.movie_admin )
+        
         self.person_entity = Person
         self.collection_getter = lambda:[Person()]
 
@@ -519,7 +540,7 @@ class FormTest(ModelThreadTestCase):
 
     def test_tab_form(self):
         form = forms.TabForm([('First tab', ['title', 'short_description']),
-                              ('Second tab', ['director', 'release_date'])])
+                              ('Second tab', ['director', 'releasedate'])])
         self.grab_widget(form.render(self.widgets))
 
     def test_group_box_form(self):
@@ -527,15 +548,15 @@ class FormTest(ModelThreadTestCase):
         self.grab_widget(form.render(self.widgets))
 
     def test_grid_form(self):
-        form = forms.GridForm([['title', 'short_description'], ['director','release_date']])
+        form = forms.GridForm([['title', 'short_description'], ['director','releasedate']])
         self.grab_widget(form.render(self.widgets))
 
     def test_vbox_form(self):
-        form = forms.VBoxForm([['title', 'short_description'], ['director', 'release_date']])
+        form = forms.VBoxForm([['title', 'short_description'], ['director', 'releasedate']])
         self.grab_widget(form.render(self.widgets))
 
     def test_hbox_form(self):
-        form = forms.HBoxForm([['title', 'short_description'], ['director', 'release_date']])
+        form = forms.HBoxForm([['title', 'short_description'], ['director', 'releasedate']])
         self.grab_widget(form.render(self.widgets))
 
     def test_nested_form(self):
@@ -553,17 +574,6 @@ class FormTest(ModelThreadTestCase):
         person_admin = Admin(self.app_admin, self.person_entity)
         self.grab_widget( person_admin.create_new_view() )
 
-from camelot.admin import form_action
-
-class FormActionTest(ModelThreadTestCase):
-
-    images_path = static_images_path
-
-    def test_print_html_form_action(self):
-        action = form_action.PrintHtmlFormAction('Summary')
-        widget = action.render(None, None)
-        self.grab_widget(widget)
-
 class DelegateTest(ModelThreadTestCase):
     """Test the basic functionallity of the delegates :
   - createEditor
@@ -590,9 +600,9 @@ class DelegateTest(ModelThreadTestCase):
 
         model = QStandardItemModel(1, 1)
         index = model.index(0, 0, QModelIndex())
-        model.setData(index, QVariant(data))
-        model.setData(index, QVariant(QtGui.QColor('white')), Qt.BackgroundRole)
-        model.setData(index, QVariant(dict(editable=True)), Qt.UserRole)
+        model.setData( index, QtCore.QVariant( data ) )
+        model.setData( index, QtCore.QVariant( QtGui.QColor('white') ), Qt.BackgroundRole )
+        model.setData( index, QtCore.QVariant( dict(editable=True) ), Qt.UserRole )
 
         option = QtGui.QStyleOptionViewItem()
 
@@ -710,6 +720,12 @@ class DelegateTest(ModelThreadTestCase):
         self.grab_delegate(delegate, 'a')
         delegate = self.delegates.EnumerationDelegate(parent=None, choices=choices, editable=False)
         self.grab_delegate(delegate, 'a', 'disabled')
+
+    def testLocalFileDelegate(self):
+        delegate = self.delegates.LocalFileDelegate(parent=None)
+        self.grab_delegate(delegate, '/home/lancelot/quests.txt')
+        delegate = self.delegates.LocalFileDelegate(parent=None, editable=False)
+        self.grab_delegate(delegate, '/home/lancelot/quests.txt', 'disabled')
         
     def testLabelDelegate(self):
         delegate = self.delegates.LabelDelegate(parent=None)
@@ -766,7 +782,7 @@ class DelegateTest(ModelThreadTestCase):
 
     def testIntervalsDelegate(self):
         from camelot.container import IntervalsContainer, Interval
-        intervals = IntervalsContainer(0, 24, [Interval(8, 18, 'work', (255,0,0,255)), Interval(19, 21, 'play', (0,255,0,255))])
+        intervals = IntervalsContainer(0, 24, [Interval(8, 18, 'work', QtGui.QColor(255,0,0,255)), Interval(19, 21, 'play', QtGui.QColor(0,255,0,255))])
         delegate = self.delegates.IntervalsDelegate(parent=None, editable=True)
         self.grab_delegate(delegate, intervals)
         delegate = self.delegates.IntervalsDelegate(parent=None, editable=False)
@@ -935,9 +951,15 @@ class ControlsTest(ModelThreadTestCase):
 
     def setUp(self):
         super(ControlsTest, self).setUp()
-        from camelot.admin.application_admin import ApplicationAdmin
-        self.app_admin = ApplicationAdmin()
+        from camelot_example.application_admin import MyApplicationAdmin
+        self.app_admin = MyApplicationAdmin()
 
+    def wait_for_animation( self ):
+        # wait a while to make sure all animations are finished
+        for i in range(10):
+            time.sleep(0.1)
+            self.app.processEvents()
+        
     def test_table_view(self):
         from camelot.view.controls.tableview import TableView
         from camelot.model.authentication import Person
@@ -945,19 +967,18 @@ class ControlsTest(ModelThreadTestCase):
         self.grab_widget(widget)
 
     def test_navigation_pane(self):
-        from camelot.admin.application_admin import ApplicationAdmin
         from camelot.view.controls import navpane2
-        
-        app_admin = ApplicationAdmin()
-        widget = navpane2.NavigationPane(app_admin,
-                                         workspace = None,
-                                         parent = None)
-        widget.set_sections( app_admin.get_sections() )
+        self.wait_for_animation()
+        widget = navpane2.NavigationPane( self.app_admin,
+                                          workspace = None,
+                                          parent = None )
+        widget.set_sections( self.app_admin.get_sections() )
         self.grab_widget(widget)
 
     def test_main_window(self):
         from camelot.view.mainwindow import MainWindow
         widget = MainWindow(self.app_admin)
+        self.wait_for_animation()
         self.grab_widget(widget)
 
     def test_status_bar(self):
@@ -981,26 +1002,26 @@ class ControlsTest(ModelThreadTestCase):
         
     def test_desktop_workspace(self):
         from camelot.view.workspace import DesktopWorkspace
-        from camelot.admin.application_action import EntityAction
+        from camelot.admin.action import Action
         from camelot.view.art import Icon
-        
+       
+        action1 = Action()
+        action1.icon=Icon('tango/32x32/places/network-server.png')
+        action2 = Action()
+        action2.icon=Icon('tango/32x32/places/user-trash.png')
+        action3 = Action()
+        action3.icon=Icon('tango/32x32/places/start-here.png')
         desktopWorkspace = DesktopWorkspace(self.app_admin, None)
-        actions = [EntityAction('Action name',
-                                None,
-                                verbose_name='Verbose action name 1',
-                                icon=Icon('tango/32x32/places/network-server.png'),
-                                notification = True),
-                   EntityAction('Action name',
-                                None,
-                                verbose_name='Verbose action name 2',
-                                icon=Icon('tango/32x32/places/user-trash.png')),
-                   EntityAction('Action name',
-                                None,
-                                verbose_name='Verbose action name 3',
-                                icon=Icon('tango/32x32/places/start-here.png'))]
-        desktopWorkspace._background_widget.set_actions(actions)
+        actions = [ action1, action2, action3 ]
+
+        desktopWorkspace._background_widget.set_actions( actions )
         self.grab_widget(desktopWorkspace)
 
+    def test_progress_dialog( self ):
+        from camelot.view.controls.progress_dialog import ProgressDialog
+        dialog = ProgressDialog( 'Import cover images' )
+        self.grab_widget( dialog )
+        
     def test_user_exception(self):
         from camelot.view.controls.exception import register_exception, ExceptionDialog
         try:
